@@ -139,6 +139,13 @@ hclu_optics <- function(dissimilarity,
     if(inherits(net, "tbl_df")){
       net <- as.data.frame(net)
     }
+    colnameindex <- index
+    if(is.numeric(colnameindex)){
+      colnameindex <- colnames(net)[index]
+      if(is.null(colnameindex)){
+        colnameindex <- NA
+      }
+    }
     net[, 3] <- net[, index]
     net <- net[, 1:3]
     controls(args = NULL, data = net, type = "input_net_index_value")
@@ -152,6 +159,7 @@ hclu_optics <- function(dissimilarity,
       attr(dist.obj, "Labels") <- paste0(1:attr(dist.obj, "Size"))
       message("No labels detected, they have been assigned automatically.")
     }
+    colnameindex <- NA
   }  
   
   if(!is.null(minPts)){
@@ -190,17 +198,21 @@ hclu_optics <- function(dissimilarity,
                        algorithm_in_output = algorithm_in_output,
                        ...)
   
+  # Determine pairwise_metric and data_type
+  pairwise_metric <- ifelse(!inherits(dissimilarity, "dist"), 
+                            colnameindex, 
+                            NA)
+  data_type <- detect_data_type_from_metric(pairwise_metric)
+  
   outputs$inputs <- list(bipartite = FALSE,
                          weight = TRUE,
                          pairwise = TRUE,
-                         pairwise_metric = ifelse(!inherits(dissimilarity, 
-                                                            "dist"), 
-                                                  ifelse(is.numeric(index), 
-                                                         names(net)[3], index), 
-                                                  NA),
+                         pairwise_metric = pairwise_metric,
                          dissimilarity = TRUE,
                          nb_sites = attr(dist.obj, "Size"),
-                         hierarchical = show_hierarchy)
+                         hierarchical = show_hierarchy,
+                         data_type = data_type,
+                         node_type = "site")
   
   outputs$algorithm <- list()
   
@@ -291,11 +303,15 @@ hclu_optics <- function(dissimilarity,
       cls_hierarchy[match(outputs$algorithm$cluster,
                           cls_hierarchy$cluster_id),
                     paste0("lvl", 1:max.col)])
+    
   }
   
   outputs$clusters[,-1][outputs$clusters[,-1]==0]=NA
   outputs$clusters <- knbclu(outputs$clusters, reorder = FALSE)
   
+  # Add node_type attribute
+  attr(outputs$clusters, "node_type") <- rep("site", dim(outputs$clusters)[1])
+  
   outputs$cluster_info <- data.frame(
     partition_name = names(outputs$clusters)[2:length(outputs$clusters),
                                              drop = FALSE],
