@@ -55,6 +55,9 @@
 #' @param algorithm_in_output A `boolean` indicating whether to include the 
 #' original output of [apcluster][apcluster::apcluster] in the result. Defaults 
 #' to `TRUE`.
+#' 
+#' @param verbose A `boolean` indicating whether to 
+#' display progress messages. Set to `FALSE` to suppress these messages.
 #'
 #' @return
 #' A `list` of class `bioregion.clusters` with five slots:
@@ -145,7 +148,8 @@ nhclu_affprop <- function(similarity,
                           prc = NULL, 
                           bimaxit = NULL, 
                           exact = NULL,
-                          algorithm_in_output = TRUE){
+                          algorithm_in_output = TRUE,
+                          verbose = TRUE){
   
   # 1. Controls ---------------------------------------------------------------
   controls(args = NULL, data = similarity, type = "input_nhandhclu")
@@ -159,6 +163,13 @@ nhclu_affprop <- function(similarity,
     if(inherits(net, "tbl_df")){
       net <- as.data.frame(net)
     }
+    colnameindex <- index
+    if(is.numeric(colnameindex)){
+      colnameindex <- colnames(net)[index]
+      if(is.null(colnameindex)){
+        colnameindex <- NA
+      }
+    }
     net[, 3] <- net[, index]
     net <- net[, 1:3]
     controls(args = NULL, data = net, type = "input_net_index_value")
@@ -174,6 +185,7 @@ nhclu_affprop <- function(similarity,
       attr(dist.obj, "Labels") <- paste0(1:attr(dist.obj, "Size"))
       message("No labels detected, they have been assigned automatically.")
     }
+    colnameindex <- NA
   }
   
   if(!is.null(seed)){
@@ -266,6 +278,7 @@ nhclu_affprop <- function(similarity,
   }
   
   controls(args = algorithm_in_output, data = NULL, type = "boolean")
+  controls(args = verbose, data = NULL, type = "boolean")
   
   sim <- NULL
   
@@ -286,19 +299,24 @@ nhclu_affprop <- function(similarity,
                        prc = prc,
                        bimaxit = bimaxit,
                        exact = exact,
-                       algorithm_in_output = algorithm_in_output)
+                       algorithm_in_output = algorithm_in_output,
+                       verbose = verbose)
+  
+  # Determine pairwise_metric and data_type
+  pairwise_metric <- ifelse(!inherits(dissimilarity, "dist"), 
+                            colnameindex, 
+                            NA)
+  data_type <- detect_data_type_from_metric(pairwise_metric)
   
   outputs$inputs <- list(bipartite = FALSE,
                          weight = TRUE,
                          pairwise = TRUE,
-                         pairwise_metric = ifelse(!inherits(similarity, 
-                                                            "dist"), 
-                                                  ifelse(is.numeric(index), 
-                                                         names(net)[3], index), 
-                                                  NA),
+                         pairwise_metric = pairwise_metric,
                          dissimilarity = FALSE,
                          nb_sites = attr(dist.obj, "Size"),
-                         hierarchical = FALSE)
+                         hierarchical = FALSE,
+                         data_type = data_type,
+                         node_type = "site")
   
   outputs$algorithm <- list()
   
@@ -319,31 +337,76 @@ nhclu_affprop <- function(similarity,
   ## 2.1. apclusterK ----------------------------------------------------------
   if(!is.null(K)){
     if(is.null(seed)){
-      outputs$algorithm <- apcluster::apclusterK(s = sim_square,
-                                                 K = K,
-                                                 prc = prc,
-                                                 bimaxit = bimaxit,
-                                                 exact = FALSE,
-                                                 maxits = maxits,
-                                                 convits = convits,
-                                                 lam = lam,
-                                                 includeSim = FALSE,
-                                                 details = details,
-                                                 nonoise = nonoise,
-                                                 seed = NA)
+      if(verbose){
+        outputs$algorithm <- apcluster::apclusterK(s = sim_square,
+                                                   K = K,
+                                                   prc = prc,
+                                                   bimaxit = bimaxit,
+                                                   exact = FALSE,
+                                                   maxits = maxits,
+                                                   convits = convits,
+                                                   lam = lam,
+                                                   includeSim = FALSE,
+                                                   details = details,
+                                                   nonoise = nonoise,
+                                                   seed = NA)
+        
+      }else{
+        tmp <- tempfile() # Catch messages from apclustersK
+        sink(tmp)   
+        on.exit(sink())    
+        
+        outputs$algorithm <- suppressMessages(suppressWarnings(
+                                  apcluster::apclusterK(s = sim_square,
+                                                        K = K,
+                                                        prc = prc,
+                                                        bimaxit = bimaxit,
+                                                        exact = FALSE,
+                                                        maxits = maxits,
+                                                        convits = convits,
+                                                        lam = lam,
+                                                        includeSim = FALSE,
+                                                        details = details,
+                                                        nonoise = nonoise,
+                                                        seed = NA)
+                             ))    
+
+      }
+
     }else{
-      outputs$algorithm <- apcluster::apclusterK(s = sim_square,
-                                                 K = K,
-                                                 prc = prc,
-                                                 bimaxit = bimaxit,
-                                                 exact = FALSE,
-                                                 maxits = maxits,
-                                                 convits = convits,
-                                                 lam = lam,
-                                                 includeSim = FALSE,
-                                                 details = details,
-                                                 nonoise = nonoise,
-                                                 seed = seed)
+      if(verbose){
+        outputs$algorithm <- apcluster::apclusterK(s = sim_square,
+                                                   K = K,
+                                                   prc = prc,
+                                                   bimaxit = bimaxit,
+                                                   exact = FALSE,
+                                                   maxits = maxits,
+                                                   convits = convits,
+                                                   lam = lam,
+                                                   includeSim = FALSE,
+                                                   details = details,
+                                                   nonoise = nonoise,
+                                                   seed = seed)
+      }else{
+        tmp <- tempfile() # Catch messages from apclustersK
+        sink(tmp)   
+        on.exit(sink())   
+        
+        outputs$algorithm <- suppressMessages(suppressWarnings(
+                                apcluster::apclusterK(s = sim_square,
+                                                      K = K,
+                                                      prc = prc,
+                                                     bimaxit = bimaxit,
+                                                     exact = FALSE,
+                                                     maxits = maxits,
+                                                     convits = convits,
+                                                     lam = lam,
+                                                     includeSim = FALSE,
+                                                     details = details,
+                                                     nonoise = nonoise,
+                                                     seed = seed)
+                            ))
+      }
     }
   }
   ## 2.2. apcluster -----------------------------------------------------------
@@ -393,6 +456,9 @@ nhclu_affprop <- function(similarity,
   
   outputs$clusters <- knbclu(outputs$clusters, reorder = TRUE)
   
+  # Add node_type attribute
+  attr(outputs$clusters, "node_type") <- rep("site", dim(outputs$clusters)[1])
+  
   outputs$cluster_info <- data.frame(
     partition_name = colnames(outputs$clusters)[2],
     n_clust = apply(outputs$clusters[, 2, drop = FALSE],
